## Geographic Decision Zones (GeoZ)


GeoZ is a Python module integrating several machine learning libraries to create Geographic Maps based on the output of 
Unsupervised Machine Learning techniques. The library is geared mainly toward delineating the output from Clustering 
algorithms, but it can be used for other Machine Learning algorithms.

See (https://github.com/Ne-oL/geoz) for complete documentation (under construction).




Created By Khalid ElHaj, PhD Fellow

Geosciences Department @ UAE University

## License information

See the file \"LICENSE.txt\" for information on the history of this software, terms & conditions for usage, and a DISCLAIMER OF ALL WARRANTIES.

